@@ -1,5 +1,5 @@
 gaussianNoiseOut <-
-function(noise, mu, varsigma) {
+function(noise, mu, varSigma) {
   D = dim(mu)[2]
   y = mu * 0
   for (i in 1:D)
