@@ -1,5 +1,6 @@
 kernExpandParam <-
 function (kern, params, untransformed.values=FALSE) {
+# browser()
   if ( is.list(params) )
     params <- params$values
   
@@ -11,12 +12,14 @@ function (kern, params, untransformed.values=FALSE) {
       func <- get(funcName$func, mode="function")
       if (funcName$hasArgs)
         params[index] <- func(params[index], "atox", kern$transformArgs[[i]])
-      else
+      else {
         params[index] <- func(params[index], "atox")
+      }
     }
 
   funcName <- paste(kern$type, "KernExpandParam", sep="")
   func <- get(funcName, mode="function")
+# browser()
   kern <- func(kern, params)
 
   return (kern)
